
%%% Temperature dependent parameters
Trif = input('Reference temperature [C] = ');
if Trif < -54
    disp('Minimum temperature: -54C');
    Trif = -54;
else if Trif > 40
        disp('Maximum temperature: 40C');
        Trif = 40;
    end
end
sim T_influence
nu = nu(end);
K_drag = K_drag(end);
K_kf = K_kf(end);
K_ks = K_ks(end);
K_ktl = K_ktl(end);
K_ktlTLPIF = K_ktlTLPIF(end);
K_c = K_c(end);

% Screw data
%%% Meaningful geometrical quantities
p=0.003175;                                                                %[m] screw step                  

%%% Friction data
fc_screw_d=0.005;                                                          %[-] power screw dynamic friction coefficient
fc_screw_s=0.005;                                                          %[-] power screw static friction coefficient
karnopp_eps_screw=0.0367;                                                  %[m/s]

%%% inertia
Jrs_RH_WT = 0.000223;                                                      %[kgm2]       
mrs_RH_WT = 0.4;                                                           %[kg]        

%%% power screw backlash data
xbl_rs_RH_WT = 0.02/1000;                                                  %[m] screw initial backlash 
K_shaft_rs_RH_WT = 7.8e8;                                                  %[N/m] equivalent contact stiffness
C_shaft_rs_RH_WT = 1E5;                                                    %[Ns/rad] equivalent contact damping factor

%*************************** ELECTRIC MOTOR DATA **************************
%%% electrical data
Zp_RH_WT = 5;                                                              %[-] number of poles couples                           
R_RH_WT = 17.81/2;                                                         %[Ohm] Phase resistance                                
L_RH_WT = 0.0412/2;                                                        %[H] Phase inductance (both mutual and not)            
k_t_RH_WT = 0.889/sqrt(3);                                                 %[Nm/A] torque constant on Iq                          
k_e_RH_WT = k_t_RH_WT/(sqrt(3/2));                                         %[Vs/rad] speed constant (single phase)  (Zp_RH_WT.*sqrt(3/2))
imax_RH_WT = 10*sqrt(2);                                                   %[A] maximum allowed current                           
Trifw = 20;                                                                %[C] Reference temperature for R,L dependencies on T  
alpha_Tw_R_RH_WT = 0.00392;                                                %[1/C] Resistance variation on temperature           
alpha_Tw_L_RH_WT = -0.0006921;                                             %[1/C] Resistance variation on flux linkage           

%%% mechanical data
c_el_belt=1250000;                                                         %[Nm/rad] belt elastic stiffness
c_m_belt = 0.4*c_el_belt;                                                  %[Nm*s/rad] belt viscous friction coefficent 
c_m0 = 1.00E-6;                                                            %[Nms/rad] Pulleys viscous friction coefficent 
Jm_RH_WT = 0.0001624;                                                      %[kg*m^2] Rotor inertia                                     
tau=1;                                                                     %[-] Belt transmission ratio
I_pulley=2.9057e-05;                                                       %[kg*m^2] Pulleys inertia

%%% thermal data
Cth_w_RH_WT = 157.4;                                                       %[J/K] windings thermal capacity                    
Cth_housing_RH_WT = 838.5;                                                 %[J/K] housing thermal capacity                     
Hth_w_RH_WT = Cth_w_RH_WT/50.66;                                           %[W/K] motor thermal conductance windings-housing   
Hth_housing_RH_WT = Hth_w_RH_WT/5;                                         %[W/K] motor thermalconductance housing-ext 

% % Fault progression switches
% Wf_TTS_ONOFF_RH_WT = 0;
% 
% 
% %%% electric motor failures
% % Weights for turn-to-turn winding shortage for EMs #1 and #2
% Wf_TTS_0_RH_WT = 0;
% Beta_TTS_RH_WT = 0;
% alpha_TTS_RH_WT = 0;

%Temperature model
Text = Trif;                                                               %[K]
T_0_RH_WT = Text;                                                          %[K]

%*************************** ELECTRONIC POWER UNIT DATA *******************
%%% EPU data
f_switch_RH_WT = 12;                                                       %[kHz] switch frequency 
T_switch_RH_WT = 1/(f_switch_RH_WT*1000);                                  %[s] switch time (PWM)  

%Transistors datas
t_on_tr=19e-9;                                                             %[s] Transistor switch on time
t_off_tr=43e-9;                                                            %[s] Transistor switch of time
R_tr=50e-3;                                                                %[Ohm] Transistor resistivity

%%% Supply data
V_dc = 270;                                                                %[V] Nominal supply voltage 
V_dcfail = 220;                                                            %[V] Minimum supply voltage 

%************************* SAMPLING SYSTEM/CONTROL DATA *******************
%%% Acquisition system data
Vel_RH_WT = 20;                                                            %[V] Voltage tension range
n_bit_RH_WT = 14;                                                          %[-] bit number
Tsampl_pos_RH_WT = 1/1000;                                                 %[s] sampling period for position control
Tsampl_w_RH_WT = 1/4000;                                                   %[s] sampling period for speed control
Tsampl_f_RH_WT = Tsampl_w_RH_WT;                                           %[s] sampling period for force-fighting compensator

%%% Microprocessor data
Tc_pos_RH_WT = 0.0002;                                                     %[s] position loop refresh and computation time
Tc_w_RH_WT = 0.00001;                                                      %[s] speed loop refresh and computation time
Tc_f_RH_WT = Tc_w_RH_WT;

%*************************** SENSOR/TRANSDUCERS DATA **********************
%%% Current measure filter
tau_i_RH_WT = 2.5E-5;                                                      %[s/rad] filter time constant CHECK

%%% LVDT parameters
Hlvdt_RH_WT = 474.9466;                                                    %[Vrms/m] LVDT gain
Vlvdt_endstop = 1;                                                         %[Vrms] Output voltage
S_lvdt_RH_WT = 1500*2*pi;                                                  %[rad/s] filter natural frequency
zeta_lvdt_RH_WT = 1;                                                       %[-] damping coefficient for RVDT

%%% resolver parameters
Hres_RH_WT = 20/(2*526);                                                   %[Vrms*s/rad] resolver gain
S_res_RH_WT = 1/(9.0787E-4)*2*pi;                                          %[rad/s] filter natural frequency
zeta_res_RH_WT = 1;                                                        %[-] damping coefficient for RVDT

%*************************** CONTROL LOOPS GAINS **************************

%%% Current gains
Kp_id_RH_WT = 50;                                                          %[V/A]
Ki_id_RH_WT = 7;                                                           %[V*s/A]
Kp_iq_RH_WT = 50;                                                          %[V/A]
Ki_iq_RH_WT = 7;                                                           %[V*s/A]

%%% speed loop
kp_w_RH_WT = 0.4;                                                          %[A/rad/s]
ki_w_RH_WT = 0.8;                                                          %[A*s/rad/s]

%%% position loop
kp_p_RH_WT = 0.50;                                                         %[1/s]
ki_p_RH_WT = 0.0;

%*************************** CRANK DATA ***********************************
% Geometric Data
I_crank = 1.1886;                                                          %[Kg*m^2] Crank inertia - center of mass
theta_0=36.8;                                                              %[deg] Initial crank position   
OP=0.1901509;                                                              %[m] Distance between the hinge "O" and "P"
OC=0.085;                                                                  %[m] Distance between the hinge "O" and "C"  
xp=73.32*1e-3;                                                             %[m] Distance pin - crank hinging

%%% Crank backlash data                                                    %[m] backlash
Kshaft_crank = 5e7;                                                        %[N/m] equivalent contact stiffness
Cshaft_crank = 1e6;                                                        %[Ns/rad] equivalent contact damping factor
xbl_crank=2e-5; %[m]

%*************************** FRICTION EXPERIMENT **************************
cross_section=27;                                                          %[m^2]
Karnopp_eps_crank=9.525e-5;                                                %[m/s]

% Null
mu_s=0; %[-]
mu_d=0; %[-]
sigma_t=160; %[N/mm^2] (+- 5)
%% Material MI 00 302
mu_s=0.7; %[-]
mu_d=0.6; %[-]
sigma_t=3; %[N/mm^2] (+- 5)

%% Material MI 00 501
mu_s=0.55; %[-]
mu_d=0.4; %[-]
sigma_t=30; %[N/mm^2] (+- 5)

%% Material 00 201
mu_s=0.52; %[-]
mu_d=0.50; %[-]
sigma_t=160; %[N/mm^2] (+- 5)

%% Material SWR
mu_s=0.55; %[-]
mu_d=0.55; %[-]
sigma_t=246; %[N/mm^2] (+- 5)





